# Custom System Messages

ToolMate AI utilizes two distinct system messages to manage tool calling and conversation:

1. Tool System Message

You can modify the tool system message to furnish ToolMate AI with details about my capabilities, constraints, or any pertinent context that may inform your interactions with ToolMate AI. This will guide ToolMate AI in managing and responding to your requests appropriately.

2. Chat System Message

You can modify the chat system message to guide our chat conversations

# To modify

Either enter `.systemmessage` in ToolMate AI prompt interface or select `change system messages` via ToolMate AI [action menu](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Action%20Menu.md).